@@ -480,6 +480,9 @@ def game_thread_run(client, url, game_code, player_code, name, color, screen_num
 
 
 def main():
+    if os.path.dirname(__file__)!='':
+        os.chdir(os.path.dirname(__file__))
+    #os.chdir(os.path.dirname(__file__))
     if len(sys.argv)==2 and sys.argv[1]=="remote":
         url = 'https://frontiersman.herokuapp.com'
         
