@@ -720,7 +720,7 @@ class Client:
 
         # print(self.player.screen_num)
         #screen_string = "localhost:0." + self.player.screen_num
-        os.putenv("DISPLAY", screen_string)
+        #os.putenv("DISPLAY", screen_string)
         os.environ['SDL_VIDEODRIVER'] = 'x11'
         '''
         if FULLSCREEN:
